DocumentParser

Trait DocumentParser 

pub trait DocumentParser<S, D, E> {
    // Required method
    fn parse(source: S) -> Result<D, E>;
}
Trait for a document parser from a S source format to a D document. Will return the parsed document or an E error.

Required Methods

fn parse(source: S) -> Result<D, E>

Parse a source and return a document or an error.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors